##############################################################################
#	Filename:	CharlestonBridge.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	This contains the code to create and configure the galaxy class bridge.
#	It is only called by LoadBridge.Initialize("galaxybridge"), so don't
#	call these functions directly
#
#	Created:	9/12/00 -	DLitwin
###############################################################################
import App

#NonSerializedObjects = ( "debug", )

#debug = App.CPyDebug(__name__).Print
#debug("Loading " + __name__ + " module...")

###############################################################################
#	CreateBridgeModel()
#
#	Create the galaxy bridge model, viewscreen and main camera, attaching them
#	to the Set passed in.
#
#	Args:	pBridgeSet	- The Bridge set
#
#	Return:	none
###############################################################################
def CreateBridgeModel(pBridgeSet):
	iDetail = App.g_kImageManager.GetImageDetail()
	pcDetail = [ "Low/", "Medium/", "High/" ]
	pcEnvPath = "data/Models/Sets/GalaxyRefit/" + pcDetail[iDetail]

	# Pre-load the Bridge model and viewscreen
	App.g_kModelManager.LoadModel("data/Models/Sets/GalaxyRefit/galaxybridge.nif", None, pcEnvPath)
	App.g_kModelManager.LoadModel("data/Models/Sets/GalaxyRefit/galaxyViewScreen.NIF", None, pcEnvPath)

	# Load the viewscreen and set it up specially with SetViewScreen()
	pViewScreen = App.ViewScreenObject_Create("data/Models/Sets/GalaxyRefit/galaxyViewScreen.NIF")
	pBridgeSet.SetViewScreen(pViewScreen, "viewscreen")

	# Setup bridge object
	pBridgeObject = App.BridgeObjectClass_Create("data/Models/Sets/GalaxyRefit/galaxybridge.nif")
	pBridgeSet.AddObjectToSet(pBridgeObject, "bridge")
	pBridgeObject.SetTranslateXYZ(0.000000, 0.000000, 0.000000)
	pBridgeObject.SetAngleAxisRotation(0.000000, 1.000000, 0.000000, 0.000000)

	# setup hardpoints for dbridge.
	pPropertySet = pBridgeObject.GetPropertySet()
	import Bridge.EBridgeProperties
	App.g_kModelPropertyManager.ClearLocalTemplates()
	reload(Bridge.EBridgeProperties)
	Bridge.EBridgeProperties.LoadPropertySet(pPropertySet)


	# Create camera
	lPos = GetBaseCameraPosition()
	pCamera = App.ZoomCameraObjectClass_Create(lPos[0], lPos[1], lPos[2], 1.570796, -0.000665, -0.087559, 0.996159, "maincamera")
	pCamera.SetMinZoom(0.8)
	pCamera.SetMaxZoom(1.0)
	pCamera.SetZoomTime(0.375)
	pBridgeSet.AddCameraToSet(pCamera, "maincamera")
	pCamera.Update( App.g_kUtopiaModule.GetGameTime() )
	App.g_kVarManager.SetFloatVariable("global", "fZoomTuneState", 0)

	# Load galaxy bridge specific sounds
	LoadSounds()

	App.g_kModelPropertyManager.ClearLocalTemplates()

###############################################################################
#	GetBaseCameraPosition
#	
#	Get the normal camera position for this bridge.
#	
#	Args:	None
#	
#	Return:	A tuple with the (x,y,z) location for the base camera position.
###############################################################################
def GetBaseCameraPosition():
	return (0, 105, 58)

###############################################################################
#	AdjustCameraPositionForBridge
#	
#	Adjust the position of the camera, based on the horizontal
#	angle it's facing, based on the bridge that it's on.
#	
#	Args:	fHorizAngle
#	
#	Return:	The adjusted camera position.
###############################################################################
def AdjustCameraPositionForBridge(pCamera, fHorizAngle):
	vLocation = App.TGPoint3()
	apply(vLocation.SetXYZ, GetBaseCameraPosition())
	return vLocation

###############################################################################
#	ConfigureCharacters()
#
#	Configure the bridge crew to the set, which adds bridge specific animations
#	to them.
#
#	Args:	pBridgeSet	- The Bridge set
#
#	Return:	none
###############################################################################
def ConfigureCharacters(pBridgeSet):
	# Configure bridge characters to our bridge
	import Bridge.Characters.galFelix
	import Bridge.Characters.galKiska
	import Bridge.Characters.galSaffi
	import Bridge.Characters.galBrex
	import Bridge.Characters.galMiguel

	import Bridge.Characters.galFemaleExtra1
	import Bridge.Characters.galFemaleExtra2
	import Bridge.Characters.galFemaleExtra3
	import Bridge.Characters.galMaleExtra1
	import Bridge.Characters.galMaleExtra2
	import Bridge.Characters.galMaleExtra3

	pgalFelix = App.CharacterClass_Cast(pBridgeSet.GetObject("Tactical"))
	pgalKiska = App.CharacterClass_Cast(pBridgeSet.GetObject("Helm"))
	pgalSaffi = App.CharacterClass_Cast(pBridgeSet.GetObject("XO"))
	pgalMiguel = App.CharacterClass_Cast(pBridgeSet.GetObject("Science"))
	pgalBrex = App.CharacterClass_Cast(pBridgeSet.GetObject("Engineer"))

	pgalFemaleExtra1 = App.CharacterClass_Cast(pBridgeSet.GetObject("FemaleExtra1"))
	pgalFemaleExtra2 = App.CharacterClass_Cast(pBridgeSet.GetObject("FemaleExtra2"))
	pgalFemaleExtra3 = App.CharacterClass_Cast(pBridgeSet.GetObject("FemaleExtra3"))

	pgalMaleExtra1 = App.CharacterClass_Cast(pBridgeSet.GetObject("MaleExtra1"))
	pgalMaleExtra2 = App.CharacterClass_Cast(pBridgeSet.GetObject("MaleExtra2"))
	pgalMaleExtra3 = App.CharacterClass_Cast(pBridgeSet.GetObject("MaleExtra3"))

	Bridge.Characters.galFelix.ConfigureForGalaxy(pgalFelix)
	Bridge.Characters.galKiska.ConfigureForGalaxy(pgalKiska)
	Bridge.Characters.galSaffi.ConfigureForGalaxy(pgalSaffi)
	Bridge.Characters.galMiguel.ConfigureForGalaxy(pgalMiguel)
	Bridge.Characters.galBrex.ConfigureForGalaxy(pgalBrex)

	if (pgalFemaleExtra1):
		Bridge.Characters.galFemaleExtra1.ConfigureForGalaxy(pgalFemaleExtra1)
	if (pgalFemaleExtra2):
		Bridge.Characters.galFemaleExtra2.ConfigureForGalaxy(pgalFemaleExtra2)
	if (pgalFemaleExtra3):
		Bridge.Characters.galFemaleExtra3.ConfigureForGalaxy(pgalFemaleExtra3)
	if (pgalMaleExtra1):
		Bridge.Characters.galMaleExtra1.ConfigureForGalaxy(pgalMaleExtra1)
	if (pgalMaleExtra2):
		Bridge.Characters.galMaleExtra2.ConfigureForGalaxy(pgalMaleExtra2)
	if (pgalMaleExtra3):
		Bridge.Characters.galMaleExtra3.ConfigureForGalaxy(pgalMaleExtra3)

	pCamera = App.ZoomCameraObjectClass_GetObject(pBridgeSet, "maincamera")
	pCamera.SetTranslateXYZ(0, 68, 50)


###############################################################################
#	LoadSounds()
#
#	Load any galaxy bridge specific sounds
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():

#	debug("Loading galaxy door sound")

	pGame = App.Game_GetCurrentGame()
	pGame.LoadSoundInGroup("sfx/door.wav",  "LiftDoor", "BridgeGeneric")


###############################################################################
#	UnloadSounds()
#
#	Unload any galaxy bridge specific sounds
#
#	Args:	none
#
#	Return:	none
###############################################################################
def UnloadSounds():
	App.g_kSoundManager.DeleteSound("LiftDoor")


###############################################################################
#	PreloadAnimations()
#
#	Load any galaxy bridge specific animations that are common
#
#	Args:	none
#
#	Return:	none
###############################################################################
def PreloadAnimations ():
	kAM = App.g_kAnimationManager

	kAM.LoadAnimation ("data/animations/gal_door_L1.nif", "gal_Door_L1")
	kAM.LoadAnimation ("data/animations/gal_door_L2.nif", "gal_Door_L2")

	# Small animations
	# Science Movement
	kAM.LoadAnimation ("data/animations/gal_stand_s_s.nif", "gal_stand_s_s")
	kAM.LoadAnimation ("data/animations/gal_seated_s_s.nif", "gal_seated_s_s")
	kAM.LoadAnimation ("data/animations/gal_face_capt_s.nif", "gal_face_capt_s")
	kAM.LoadAnimation ("data/animations/gal_chair_s_face_capt.nif", "gal_chair_s_face_capt")
	kAM.LoadAnimation ("data/animations/gal_face_capt_s_reverse.nif", "gal_face_capt_s_reverse")
	kAM.LoadAnimation ("data/animations/gal_chair_s_face_capt_reverse.nif", "gal_chair_s_face_capt_reverse")
	kAM.LoadAnimation ("data/animations/EB_chair_S_in.nif", "EB_chair_S_in")

	# Science Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/EB_S_pushing_buttons_seated_A.NIF", "EB_S_pushing_buttons_seated_A")
	kAM.LoadAnimation ("data/animations/EB_S_pushing_buttons_seated_B.NIF", "EB_S_pushing_buttons_seated_B")
	kAM.LoadAnimation ("data/animations/EB_S_pushing_buttons_seated_C.NIF", "EB_S_pushing_buttons_seated_C")

	# Science Talking to other stations

	# Engineer Movement
	kAM.LoadAnimation ("data/animations/gal_stand_e_s.nif", "gal_stand_e_s")
	kAM.LoadAnimation ("data/animations/gal_seated_e_s.nif", "gal_seated_e_s")
	kAM.LoadAnimation ("data/animations/gal_face_capt_e.nif", "gal_face_capt_e")
	kAM.LoadAnimation ("data/animations/gal_chair_e_face_capt.nif", "gal_chair_e_face_capt")
	kAM.LoadAnimation ("data/animations/gal_face_capt_e_reverse.nif", "gal_face_capt_e_reverse")
	kAM.LoadAnimation ("data/animations/gal_chair_e_face_capt_reverse.nif", "gal_chair_e_face_capt_reverse")
	kAM.LoadAnimation ("data/animations/EB_chair_E_in.nif", "EB_chair_E_in")

	# Engineer Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_A.NIF", "EB_E_pushing_buttons_seated_A")
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_B.NIF", "EB_E_pushing_buttons_seated_B")
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_C.NIF", "EB_E_pushing_buttons_seated_C")

	# Engineer Talking to other stations

	# 
	# medium animations
	# Helm Movement
	kAM.LoadAnimation ("data/animations/gal_stand_h_m.nif", "gal_stand_h_m")
	kAM.LoadAnimation ("data/animations/gal_seated_h_m.nif", "gal_seated_h_m")
	kAM.LoadAnimation ("data/animations/gal_face_capt_h.nif", "gal_face_capt_h")
	kAM.LoadAnimation ("data/animations/gal_chair_H_face_capt.nif", "gal_chair_H_face_capt")
	kAM.LoadAnimation ("data/animations/gal_face_capt_h_reverse.nif", "gal_face_capt_h_reverse")
	kAM.LoadAnimation ("data/animations/gal_chair_H_face_capt_reverse.nif", "gal_chair_H_face_capt_reverse")
	kAM.LoadAnimation ("data/animations/EB_glance_h_m.nif", "gal_glance_h_m")
	kAM.LoadAnimation ("data/animations/EB_glance_h_m_reverse.nif", "gal_glance_h_m_reverse")

	kAM.LoadAnimation ("data/animations/EB_hit_h.NIF", "gal_hit_h")


	# Helm Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/EB_H_Console_Slide_A.NIF", "EB_H_console_slide_A")
	kAM.LoadAnimation ("data/animations/EB_H_Console_Slide_B.NIF", "EB_H_console_slide_B")
	kAM.LoadAnimation ("data/animations/EB_H_Console_Slide_C.NIF", "EB_H_console_slide_C")
	kAM.LoadAnimation ("data/animations/EB_H_Console_Slide_D.NIF", "EB_H_console_slide_D")

	kAM.LoadAnimation ("data/animations/EB_H_pushing_buttons_A.NIF", "EB_H_pushing_buttons_A")
	kAM.LoadAnimation ("data/animations/EB_H_pushing_buttons_B.NIF", "EB_H_pushing_buttons_B")
	kAM.LoadAnimation ("data/animations/EB_H_pushing_buttons_C.NIF", "EB_H_pushing_buttons_C")
	kAM.LoadAnimation ("data/animations/EB_H_pushing_buttons_D.NIF", "EB_H_pushing_buttons_D")
	kAM.LoadAnimation ("data/animations/EB_H_pushing_buttons_E.NIF", "EB_H_pushing_buttons_E")
	kAM.LoadAnimation ("data/animations/EB_H_pushing_buttons_F.NIF", "EB_H_pushing_buttons_F")

	# Helm Talking to other stations
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_C_M.NIF", "EB_H_Talk_to_C_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_E_M.NIF", "EB_H_Talk_to_E_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_S_M.NIF", "EB_H_Talk_to_S_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_T_M.NIF", "EB_H_Talk_to_T_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_C_M.NIF", "EB_H_Talk_fin_C_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_E_M.NIF", "EB_H_Talk_fin_E_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_S_M.NIF", "EB_H_Talk_fin_S_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_T_M.NIF", "EB_H_Talk_fin_T_M")

	# XO Movement
	kAM.LoadAnimation ("data/animations/gal_seated_C_M.nif", "gal_seated_c_m")
	kAM.LoadAnimation ("data/animations/gal_seatedm_C_M.nif", "gal_seatedm_c_m")
	kAM.LoadAnimation ("data/animations/gal_stand_V_M.nif", "gal_stand_c_m")
	kAM.LoadAnimation ("data/animations/gal_face_capt_c1.nif", "gal_face_capt_c1")
	kAM.LoadAnimation ("data/animations/gal_face_capt_c.nif", "gal_face_capt_c")
	kAM.LoadAnimation ("data/animations/gal_face_capt_C_reverse.NIF", "gal_face_capt_C_reverse")
	kAM.LoadAnimation ("data/animations/gal_face_capt_c1_reverse.NIF", "gal_face_capt_c1_reverse")
	kAM.LoadAnimation ("data/animations/EB_hit_c.NIF", "Int_hit_c")

	#Commander interaction
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_A.NIF", "DB_C_pushing_buttons_seated_A")
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_B.NIF", "DB_C_pushing_buttons_seated_B")
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_C.NIF", "DB_C_pushing_buttons_seated_C")
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_D.NIF", "DB_C_pushing_buttons_seated_D")
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_E.NIF", "DB_C_pushing_buttons_seated_E")
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_F.NIF", "DB_C_pushing_buttons_seated_F")
	kAM.LoadAnimation ("data/animations/DB_C_pushing_buttons_G.NIF", "DB_C_pushing_buttons_seated_G")

	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_A.NIF", "DB_X_pushing_buttons_A")
	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_B.NIF", "DB_X_pushing_buttons_B")
	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_C.NIF", "DB_X_pushing_buttons_C")
	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_D.NIF", "DB_X_pushing_buttons_D")
	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_E.NIF", "DB_X_pushing_buttons_E")
	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_F.NIF", "DB_X_pushing_buttons_F")
	kAM.LoadAnimation ("data/animations/DB_X_pushing_buttons_G.NIF", "DB_X_pushing_buttons_G")

	# XO Talking to other stations
	kAM.LoadAnimation ("data/animations/DB_C_Talk_E_M.NIF", "DB_C_Talk_E_M")
	kAM.LoadAnimation ("data/animations/DB_C_Talk_G2_M.NIF", "DB_C_Talk_G2_M")
	kAM.LoadAnimation ("data/animations/DB_C_Talk_G3_M.NIF", "DB_C_Talk_G3_M")
	kAM.LoadAnimation ("data/animations/DB_C_Talk_TH_M.NIF", "DB_C_Talk_TH_M")
	kAM.LoadAnimation ("data/animations/DB_C_Talk_S_M.NIF", "DB_C_Talk_S_M")

	# Guest Animations
	kAM.LoadAnimation ("data/animations/DB_L1toX_M.nif", "EB_L1toX_M")
	kAM.LoadAnimation ("data/animations/DB_seated_X_m.nif", "EB_seated_X_m")
	kAM.LoadAnimation ("data/animations/DB_face_capt_X.nif", "EB_face_capt_X")
	kAM.LoadAnimation ("data/animations/DB_face_capt_X_reverse.NIF", "EB_face_capt_X_reverse")
	kAM.LoadAnimation ("data/animations/DB_hit_x.NIF", "gal_hit_x")

	# Extras
	kAM.LoadAnimation ("data/animations/gal_L1toG3_S.nif", "gal_L1toG3_S")
	kAM.LoadAnimation ("data/animations/gal_L1toG3_M.nif", "gal_L1toG3_M")
	kAM.LoadAnimation ("data/animations/gal_L1toG3_L.nif", "gal_L1toG3_L")

	kAM.LoadAnimation ("data/animations/gal_L2toG1_S.nif", "gal_L2toG1_S")
	kAM.LoadAnimation ("data/animations/gal_L2toG1_M.nif", "gal_L2toG1_M")
	kAM.LoadAnimation ("data/animations/gal_L2toG1_L.nif", "gal_L2toG1_L")

	kAM.LoadAnimation ("data/animations/gal_L2toG2_S.nif", "gal_L2toG2_S")
	kAM.LoadAnimation ("data/animations/gal_L2toG2_M.nif", "gal_L2toG2_M")
	kAM.LoadAnimation ("data/animations/gal_L2toG2_L.nif", "gal_L2toG2_L")

	kAM.LoadAnimation ("data/animations/gal_G1toL2_S.nif", "gal_G1toL2_S")
	kAM.LoadAnimation ("data/animations/gal_G1toL2_M.nif", "gal_G1toL2_M")
	kAM.LoadAnimation ("data/animations/gal_G1toL2_L.nif", "gal_G1toL2_L")
	
	kAM.LoadAnimation ("data/animations/gal_G2toL2_S.nif", "gal_G2toL2_S")
	kAM.LoadAnimation ("data/animations/gal_G2toL2_M.nif", "gal_G2toL2_M")
	kAM.LoadAnimation ("data/animations/gal_G2toL2_L.nif", "gal_G2toL2_L")
	
	kAM.LoadAnimation ("data/animations/gal_G3toL1_S.nif", "gal_G3toL1_S")
	kAM.LoadAnimation ("data/animations/gal_G3toL1_M.nif", "gal_G3toL1_M")
	kAM.LoadAnimation ("data/animations/gal_G3toL1_L.nif", "gal_G3toL1_L")

	kAM.LoadAnimation ("data/animations/gal_seated_XT01.NIF", "gal_seated_XT01")
	kAM.LoadAnimation ("data/animations/gal_seated_XT02.NIF", "gal_seated_XT02")
	kAM.LoadAnimation ("data/animations/gal_standing_XT03.NIF", "gal_standing_XT03")
	kAM.LoadAnimation ("data/animations/gal_interaction_XT01.NIF", "gal_interaction_XT01")
	kAM.LoadAnimation ("data/animations/gal_interaction_XT02.NIF", "gal_interaction_XT02")

	# Large animations
	# Tactical Movement
	kAM.LoadAnimation ("data/animations/gal_stand_t_l.nif", "gal_stand_t_l")
	kAM.LoadAnimation ("data/animations/gal_seated_t_l.nif", "gal_seated_t_l")
	kAM.LoadAnimation ("data/animations/gal_seatedm_t_l.nif", "gal_seatedm_t_l")
	kAM.LoadAnimation ("data/animations/gal_face_capt_t.nif", "gal_face_capt_t")
	kAM.LoadAnimation ("data/animations/gal_chair_T_face_capt.nif", "gal_chair_T_face_capt")
	kAM.LoadAnimation ("data/animations/gal_face_capt_t_reverse.nif", "gal_face_capt_t_reverse")
	kAM.LoadAnimation ("data/animations/gal_chair_T_face_capt_reverse.nif", "gal_chair_T_face_capt_reverse")
	kAM.LoadAnimation ("data/animations/EB_hit_t.NIF", "gal_hit_t")

	# Tactical Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/DB_T_Console_Slide_A.NIF", "EB_T_console_slide_A")
	kAM.LoadAnimation ("data/animations/EB_T_Console_Slide_B.NIF", "EB_T_console_slide_B")
	kAM.LoadAnimation ("data/animations/EB_T_Console_Slide_C.NIF", "EB_T_console_slide_C")
	kAM.LoadAnimation ("data/animations/EB_T_Console_Slide_D.NIF", "EB_T_console_slide_D")

	kAM.LoadAnimation ("data/animations/EB_T_pushing_buttons_A.NIF", "EB_T_pushing_buttons_A")
	kAM.LoadAnimation ("data/animations/EB_T_pushing_buttons_B.NIF", "EB_T_pushing_buttons_B")
	kAM.LoadAnimation ("data/animations/EB_T_pushing_buttons_C.NIF", "EB_T_pushing_buttons_C")
	kAM.LoadAnimation ("data/animations/EB_T_pushing_buttons_D.NIF", "EB_T_pushing_buttons_D")
	kAM.LoadAnimation ("data/animations/EB_T_pushing_buttons_E.NIF", "EB_T_pushing_buttons_E")
	kAM.LoadAnimation ("data/animations/EB_T_pushing_buttons_F.NIF", "EB_T_pushing_buttons_F")

	# Tactical Talking to other stations
	kAM.LoadAnimation ("data/animations/EB_T_Talk_to_H_L.NIF", "EB_T_Talk_to_H_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_to_G2_L.NIF", "EB_T_Talk_to_G2_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_to_G3_L.NIF", "EB_T_Talk_to_G3_L")

	kAM.LoadAnimation ("data/animations/EB_T_Talk_fin_H_L.NIF", "EB_T_Talk_fin_H_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_fin_G2_L.NIF", "EB_T_Talk_fin_G2_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_fin_G3_L.NIF", "EB_T_Talk_fin_G3_L")

	return

###############################################################################
#	UnloadAnimations()
#
#	Unload any galaxy bridge specific animations that are common
#
#	Args:	none
#
#	Return:	none
###############################################################################
def UnloadAnimations ():
	kAM = App.g_kAnimationManager

	kAM.FreeAnimation("gal_Door_L1")
	kAM.FreeAnimation("gal_Door_L2")

	# Small animations
	# Science Movement
	kAM.FreeAnimation("gal_stand_s_s")
	kAM.FreeAnimation("gal_seated_s_s")
	kAM.FreeAnimation("gal_face_capt_s")
	kAM.FreeAnimation("gal_chair_s_face_capt")
	kAM.FreeAnimation("gal_face_capt_s_reverse")
	kAM.FreeAnimation("gal_chair_s_face_capt_reverse")
	kAM.FreeAnimation("EB_chair_S_in")

	# Science Console Slides and Button Pushes
	kAM.FreeAnimation("EB_S_pushing_buttons_seated_A")
	kAM.FreeAnimation("EB_S_pushing_buttons_seated_B")
	kAM.FreeAnimation("EB_S_pushing_buttons_seated_C")

	# Science Talking to other stations

	# Engineer Movement
	kAM.FreeAnimation("gal_stand_e_s")
	kAM.FreeAnimation("gal_seated_e_s")
	kAM.FreeAnimation("gal_face_capt_e")
	kAM.FreeAnimation("gal_chair_e_face_capt")
	kAM.FreeAnimation("gal_face_capt_e_reverse")
	kAM.FreeAnimation("gal_chair_e_face_capt_reverse")
	kAM.FreeAnimation("EB_chair_E_in")

	# Engineer Console Slides and Button Pushes
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_A")
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_B")
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_C")

	# Engineer Talking to other stations

	# medium animations
	# Helm Movement
	kAM.FreeAnimation("gal_stand_h_m")
	kAM.FreeAnimation("gal_seated_h_m")
	kAM.FreeAnimation("gal_face_capt_h")
	kAM.FreeAnimation("gal_face_capt_h_reverse")
	kAM.FreeAnimation("gal_hit_h")


	# Helm Console Slides and Button Pushes
	kAM.FreeAnimation("EB_H_console_slide_A")
	kAM.FreeAnimation("EB_H_console_slide_B")
	kAM.FreeAnimation("EB_H_console_slide_C")
	kAM.FreeAnimation("EB_H_console_slide_D")

	kAM.FreeAnimation("EB_H_pushing_buttons_A")
	kAM.FreeAnimation("EB_H_pushing_buttons_B")
	kAM.FreeAnimation("EB_H_pushing_buttons_C")
	kAM.FreeAnimation("EB_H_pushing_buttons_D")
	kAM.FreeAnimation("EB_H_pushing_buttons_E")
	kAM.FreeAnimation("EB_H_pushing_buttons_F")

	# Helm Talking to other stations
	kAM.FreeAnimation("EB_H_Talk_to_C_M")
	kAM.FreeAnimation("EB_H_Talk_to_E_M")
	kAM.FreeAnimation("EB_H_Talk_to_S_M")
	kAM.FreeAnimation("EB_H_Talk_to_T_M")
	kAM.FreeAnimation("EB_H_Talk_fin_C_M")
	kAM.FreeAnimation("EB_H_Talk_fin_E_M")
	kAM.FreeAnimation("EB_H_Talk_fin_S_M")
	kAM.FreeAnimation("EB_H_Talk_fin_T_M")

	# XO Movement
	kAM.FreeAnimation("gal_seated_c_m")
	kAM.FreeAnimation("gal_seatedm_c_m")
	kAM.FreeAnimation("gal_stand_c_m")
	kAM.FreeAnimation("gal_face_capt_c1")
	kAM.FreeAnimation("gal_face_capt_c")
	kAM.FreeAnimation("gal_face_capt_C_reverse")
	kAM.FreeAnimation("gal_face_capt_c1_reverse")
	kAM.FreeAnimation("gal_hit_c")
	kAM.FreeAnimation("gal_stand_D_M")
	kAM.FreeAnimation("gal_seated_D_M")


	# XO Console Slides and Button Pushes
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_A")
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_B")
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_C")
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_D")
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_E")
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_F")
	kAM.FreeAnimation("DB_C_pushing_buttons_seated_G")

	# XO Talking to other stations
	kAM.FreeAnimation("DB_C_Talk_E_M")
	kAM.FreeAnimation("DB_C_Talk_H_M")
	kAM.FreeAnimation("DB_C_Talk_T_M")
	kAM.FreeAnimation("DB_C_Talk_S_M")

	# Guest Animations
	kAM.FreeAnimation("EB_L1toX_M")
	kAM.FreeAnimation("EB_seated_X_m")
	kAM.FreeAnimation("EB_face_capt_X")
	kAM.FreeAnimation("EB_face_capt_X_reverse")
	kAM.FreeAnimation("gal_hit_x")

	kAM.FreeAnimation("EB_X_pushing_buttons_A")
	kAM.FreeAnimation("EB_X_pushing_buttons_B")
	kAM.FreeAnimation("EB_X_pushing_buttons_C")
	kAM.FreeAnimation("EB_X_pushing_buttons_D")
	kAM.FreeAnimation("EB_X_pushing_buttons_E")
	kAM.FreeAnimation("EB_X_pushing_buttons_F")
	kAM.FreeAnimation("EB_X_pushing_buttons_G")

	#Extra
	kAM.FreeAnimation("gal_L1toG3_S")
	kAM.FreeAnimation("gal_L1toG3_M")
	kAM.FreeAnimation("gal_L1toG3_L")

	kAM.FreeAnimation("gal_L2toG1_S")
	kAM.FreeAnimation("gal_L2toG1_M")
	kAM.FreeAnimation("gal_L2toG1_L")

	kAM.FreeAnimation("gal_L2toG2_S")
	kAM.FreeAnimation("gal_L2toG2_M")
	kAM.FreeAnimation("gal_L2toG2_L")

	kAM.FreeAnimation("gal_G1toL2_S")
	kAM.FreeAnimation("gal_G1toL2_M")
	kAM.FreeAnimation("gal_G1toL2_L")
	
	kAM.FreeAnimation("gal_G2toL2_S")
	kAM.FreeAnimation("gal_G2toL2_M")
	kAM.FreeAnimation("gal_G2toL2_L")
	
	kAM.FreeAnimation("gal_G3toL1_S")
	kAM.FreeAnimation("gal_G3toL1_M")
	kAM.FreeAnimation("gal_G3toL1_L")

	kAM.FreeAnimation("gal_seated_XT01")
	kAM.FreeAnimation("gal_seated_XT02")
	kAM.FreeAnimation("gal_standing_XT03")
	kAM.FreeAnimation("gal_interaction_XT01")
	kAM.FreeAnimation("gal_interaction_XT02")
	
	# Large animations
	# Tactical Movement
	kAM.FreeAnimation("gal_stand_t_l")
	kAM.FreeAnimation("gal_seated_t_l")
	kAM.FreeAnimation("gal_seatedm_t_l")
	kAM.FreeAnimation("gal_face_capt_t")
	kAM.FreeAnimation("gal_chair_T_face_capt")
	kAM.FreeAnimation("gal_face_capt_t_reverse")
	kAM.FreeAnimation("gal_chair_T_face_capt_reverse")
	kAM.FreeAnimation("gal_hit_t")

	# Tactical Console Slides and Button Pushes
	kAM.FreeAnimation("EB_T_console_slide_A")
	kAM.FreeAnimation("EB_T_console_slide_B")
	kAM.FreeAnimation("EB_T_console_slide_C")
	kAM.FreeAnimation("EB_T_console_slide_D")

	kAM.FreeAnimation("EB_T_pushing_buttons_A")
	kAM.FreeAnimation("EB_T_pushing_buttons_B")
	kAM.FreeAnimation("EB_T_pushing_buttons_C")
	kAM.FreeAnimation("EB_T_pushing_buttons_D")
	kAM.FreeAnimation("EB_T_pushing_buttons_E")
	kAM.FreeAnimation("EB_T_pushing_buttons_F")

	# Tactical Talking to other stations
	kAM.FreeAnimation("EB_T_Talk_to_H_L")
	kAM.FreeAnimation("EB_T_Talk_to_G2_L")
	kAM.FreeAnimation("EB_T_Talk_to_G3_L")

	kAM.FreeAnimation("EB_T_Talk_fin_H_L")
	kAM.FreeAnimation("EB_T_Talk_fin_G2_L")
	kAM.FreeAnimation("EB_T_Talk_fin_G3_L")


	return
